Author: Scott Kirkwood

# Sample Presentation

## This is a subtitle

### Scott Kirkwood

#### Scott's Company

# Introduction

- mm2s5 creates a simple presentation from a FreeMind mind map
- Each slide page has line items

- That can

- be nested

- to any

- depth

# Tricks

- You can enter any HTMLtags
- If your FreeMind node starts with a < it will not put it in in a list item
- If you're have a node with next "__table__" the child elements will be considered row and columns of a table.

# Tables

Simple tables can be put in relatively easily

Based on concentrations (ppb) adjusted for heat retention characteristics | Percent of Total | Percent of total - ajusted for water vapor
Water Vapor (H20) | --- | 95.000%
Carbon Dioxide (CO2) | 72.369% | 3.618%
Methane (CH4) | 7.100% | 0.360%
Nitrous oxide (N2O) | 19.000% | 0.950%
CFC + Other gases | 1.432% | 0.072%
Total | 100% | 100%

Borrowed from Geocraft site

# Ordered List

1. Put purple 1 icon on the parent node
2. and
3. the items
4. will be
5. numbered

# No list

Put a green check on the slide And the items below won't appears as a list

- But sub-sub items
- still will

# Stop Light

- The stoplight icon
- Will make your
- Slide build one
- row at a
- time

# Skip a slide

You can skip a slide like the previous one, which you didn't see.

# Pros

Advantages of mm2s5

- Very quick and easy
- FreeMind has a great GUI and is very intuitive to use
- FreeMind and S5 are actively supported
- FreeMinds, S5 and mm2s5 are all cross platform
- FreeMind is useful for more than just presentations :-)
- You can create nice presentations templates in CSS

# Cons

Problems with mm2s5

- Need to edit/compile/test your presentations
- You need to remember to save in FreeMind
- Everytime you refresh your presentation in the browser, you start on page 1
- No support for notes in the new S5 version

- Hey, but that's where you can help!

# Conclusions

- If you stick to a simple presentations you can create something very quickly and easily
- S5 is cross platform and you can show it anywhere
- For longer presentations, you may find the edit/compile/test process tedious

# Links

- FreeMind
- S5

- mm2s5 is known to work withS5 v1.1
- untested with the newer S5 Project

- mm2s5